/// <reference types="react" />
import type { ContextMenuProps } from "@components/ContextMenu";
import type { ContextMenuTypes, GetContextItem } from "../../../types/coremods/contextMenu";
export declare const menuItems: Record<ContextMenuTypes, {
    getItem: GetContextItem;
    sectionId: number | undefined;
    indexInSection: number;
}[] | undefined>;
/**
 * Add an item to any context menu
 * @param navId The id of the menu you want to insert to
 * @param getItem A function that creates and returns the menu item
 * @param sectionId The number of the section to add to. Defaults to replugged's section
 * @param indexInSection The index in the section to add to. Defaults to the end position
 * @returns A callback to de-register the function
 */
export declare function addContextMenuItem(navId: ContextMenuTypes, getItem: GetContextItem, sectionId: number | undefined, indexInSection: number): () => void;
/**
 * Remove an item from a context menu
 * @param navId The id of the menu the function was registered to
 * @param getItem The function to remove
 * @returns
 */
export declare function removeContextMenuItem(navId: ContextMenuTypes, getItem: GetContextItem): void;
type ContextMenuData = ContextMenuProps["ContextMenu"] & {
    children: React.ReactElement | React.ReactElement[];
    data: Array<Record<string, unknown>>;
    navId: ContextMenuTypes;
    plugged?: boolean;
};
/**
 * @internal
 * @hidden
 */
export declare function _insertMenuItems(menu: ContextMenuData): void;
export {};
