import type { RepluggedTheme } from "../../types";
/**
 * @hidden
 */
export declare const themes: Map<string, RepluggedTheme>;
/**
 * Load metadata for all themes that are added to the themes folder but not yet loaded, such as newly added themes.
 *
 * @remarks
 * This does not apply the themes, only loads their metadata. You can call {@link load} or {@link loadAll} to apply a theme.
 */
export declare function loadMissing(): Promise<void>;
/**
 * Unload a theme, removing its stylesheet from the DOM
 * @param id Theme ID (RDNN)
 */
export declare function unload(id: string): void;
/**
 * Load a theme's main variant, adding its stylesheet to the DOM
 * @param id Theme ID (RDNN)
 */
export declare function load(id: string): void;
/**
 * Load a theme's splash variant, adding its stylesheet to the DOM
 * @param id Theme ID (RDNN)
 */
export declare function loadSplash(id: string): void;
/**
 * Load all themes' main variants, adding their stylesheets to the DOM. Disabled themes are not loaded.
 */
export declare function loadAll(): void;
/**
 * Load all themes' splash variants, adding their stylesheets to the DOM. Disabled themes are not loaded.
 */
export declare function loadAllSplash(): void;
/**
 * Unload all themes, removing their stylesheets from the DOM
 */
export declare function unloadAll(): void;
/**
 * Get a theme
 *
 * @remarks
 * This may include themes that are not available until Discord is reloaded.
 */
export declare function get(path: string): Promise<RepluggedTheme | undefined>;
/**
 * List all themes
 *
 * @remarks
 * This may include themes that are not available until Discord is reloaded.
 */
export declare function list(): Promise<RepluggedTheme[]>;
/**
 * Reload a theme's main variant to apply changes
 */
export declare function reload(id: string): void;
/**
 * Reload a theme's splash variant to apply changes
 */
export declare function reloadSplash(id: string): void;
export declare function enable(id: string): void;
export declare function disable(id: string): void;
export declare function uninstall(id: string): Promise<void>;
export declare function getDisabled(): string[];
