/// <reference types="node" />
import type { ProgressEvent, Request, Response } from "superagent";
interface HTTPAttachment {
    file: string | Blob | Buffer;
    filename: string;
    name: string;
}
interface HTTPField {
    name: string;
    value: string;
}
interface HTTPRequest {
    url: string;
    attachments?: HTTPAttachment[];
    backoff?: Backoff;
    binary?: boolean;
    body?: Record<string, unknown>;
    context?: Record<string, unknown>;
    fields?: HTTPField[];
    headers?: Record<string, string>;
    oldFormErrors?: boolean;
    query?: string | Record<string, string>;
    reason?: string;
    retried?: number;
    retries?: number;
    signal?: AbortSignal;
    timeout?: number;
    interceptResponse?: (response: Response, retry: (headers?: Record<string, string>, interceptResponse?: HTTPRequest["interceptResponse"]) => void, reject: (reason: Error) => void) => void;
    onRequestCreated?: (request: Request) => void;
    onRequestProgress?: (progress: ProgressEvent) => void;
}
interface HTTPResponse<T = Record<string, unknown>> {
    body: T;
    headers: Record<string, string>;
    ok: boolean;
    status: number;
    text: string;
}
export declare class Backoff {
    constructor(min?: number, max?: number | null, jitter?: boolean);
    private _callback?;
    private _current;
    private _fails;
    private _timeoutId?;
    jitter: boolean;
    max: number;
    min: number;
    get current(): number;
    get fails(): number;
    get pending(): boolean;
    cancel: () => void;
    fail: (callback?: () => void) => number;
    succeed: () => void;
}
declare class V6OrEarlierAPIError {
    constructor(error: Record<string, unknown> | null, code: number, message?: string);
    code: number;
    error: Error;
    fields: Record<string, unknown>;
    message: string;
    retryAfter: number | undefined;
    status: number;
    getFieldMessage: (field: string) => unknown;
}
export declare class APIError {
    constructor(error: Record<string, unknown> | null, code: number, message?: string);
    captchaFields: Record<string, unknown>;
    code: number;
    errors: Record<string, {
        _errors: Array<{
            code: string;
            message: string;
        }>;
    }> | undefined;
    message: string;
    retryAfter: number | undefined;
    status: number;
    getAnyErrorMessage: () => string | {
        fieldName: string | null;
        error: string;
    };
    getAnyErrorMessageAndField: () => {
        fieldName: string | null;
        error: string;
    } | null;
    getFieldErrors: (field: string | string[]) => Array<{
        code: string;
        message: string;
    }> | undefined;
    getFirstFieldErrorMessage: (field: string | string[]) => string | null;
    hasFieldErrors: () => boolean;
}
export type API = Record<"get" | "patch" | "post" | "put" | "delete", <T = Record<string, unknown>>(req: string | HTTPRequest, callback?: (response: HTTPResponse) => void) => Promise<HTTPResponse<T>>> & {
    getAPIBaseURL: (version?: boolean) => string;
    V6OrEarlierAPIError: typeof V6OrEarlierAPIError;
    V8APIError: typeof APIError;
};
declare const _default: API;
export default _default;
