/// <reference types="react" />
declare enum ModalTransitionState {
    ENTERING = 0,
    ENTERED = 1,
    EXITING = 2,
    EXITED = 3,
    HIDDEN = 4
}
export interface ModalProps {
    transitionState: ModalTransitionState;
    onClose(): Promise<void>;
}
export interface ModalOptions {
    modalKey?: string;
    instant?: boolean;
    onCloseRequest?: () => void;
    onCloseCallback?: () => void;
}
interface ModalClasses {
    Direction: Record<"HORIZONTAL" | "HORIZONTAL_REVERSE" | "VERTICAL", string>;
    Align: Record<"BASELINE" | "CENTER" | "END" | "START" | "STRETCH", string>;
    Justify: Record<"AROUND" | "BETWEEN" | "CENTER" | "END" | "START", string>;
    Wrap: Record<"WRAP" | "NO_WRAP" | "WRAP_REVERSE", string>;
}
interface AlertProps {
    title?: string;
    body?: string | React.ReactElement;
    confirmColor?: string;
    confirmText?: string;
    cancelText?: string;
    onConfirm?: () => void;
    onCancel?: () => void;
    onCloseCallback?: () => void;
    secondaryConfirmText?: string;
    onConfirmSecondary?: () => void;
    className?: string;
    titleClassName?: string;
}
export type Modal = {
    openModal: (render: (props: ModalProps) => React.ReactNode, options?: ModalOptions, contextKey?: string) => string;
    closeModal: (modalKey: string, contextKey?: string) => void;
    alert: (props: AlertProps) => void;
    confirm: (props: AlertProps) => Promise<boolean | null>;
} & ModalClasses;
declare const _default: Modal;
export default _default;
