import type { RawModule } from "../../../types";
/**
 * Get a module that has all the given properties on one of its exports
 * @param props List of property names
 */
export declare const byProps: <P extends PropertyKey = PropertyKey>(...props: P[]) => (m: RawModule) => boolean;
/**
 * Get a module whose source code matches the given string or RegExp
 * @param match String or RegExp to match in the module's source code
 *
 * @remarks
 * This function matches on the minified code, so make sure to keep that in mind
 * when writing your strings/regex.
 * Randomized variable names (usually 1-2 letters) are not stable between Discord updates.
 * Make sure to use wildcards to make sure your RegExp matches if the variable name were to change.
 */
export declare const bySource: (match: string | RegExp) => (m: RawModule) => boolean;
/**
 * Get a module that has the given value on one of its exports
 * @param match The string to check the value against
 *
 * @example
 * ```
 * const classes = getModule(filters.byValue("container-2sjPya"));
 * ```
 *
 * @remarks
 * Great for getting a module for a specific class name
 */
export declare const byValue: (match: string | RegExp) => (m: RawModule) => boolean;
