/// <reference types="react" />
import { z } from "zod";
import type { Promisable } from "type-fest";
export declare const id: z.ZodString;
export type Id = z.infer<typeof id>;
export declare const author: z.ZodObject<{
    name: z.ZodString;
    discordID: z.ZodOptional<z.ZodString>;
    github: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    name: string;
    discordID?: string | undefined;
    github?: string | undefined;
}, {
    name: string;
    discordID?: string | undefined;
    github?: string | undefined;
}>;
export type Author = z.infer<typeof author>;
export declare const common: z.ZodObject<{
    id: z.ZodString;
    name: z.ZodString;
    description: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    version: z.ZodString;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
}, {
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
}>;
export type Common = z.infer<typeof common>;
export declare const repluggedManifest: z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged">;
}, "strip", z.ZodTypeAny, {
    type: "replugged";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
}, {
    type: "replugged";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
}>;
export type RepluggedManifest = z.infer<typeof repluggedManifest>;
export interface RepluggedEntity {
    manifest: RepluggedManifest;
    path: string;
}
export declare const theme: z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged-theme">;
    main: z.ZodOptional<z.ZodString>;
    splash: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: "replugged-theme";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    main?: string | undefined;
    splash?: string | undefined;
}, {
    type: "replugged-theme";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    main?: string | undefined;
    splash?: string | undefined;
}>;
export type ThemeManifest = z.infer<typeof theme>;
export declare const plugin: z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged-plugin">;
    renderer: z.ZodOptional<z.ZodString>;
    plaintextPatches: z.ZodOptional<z.ZodString>;
    reloadRequired: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    type: "replugged-plugin";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    renderer?: string | undefined;
    plaintextPatches?: string | undefined;
    reloadRequired?: boolean | undefined;
}, {
    type: "replugged-plugin";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    renderer?: string | undefined;
    plaintextPatches?: string | undefined;
    reloadRequired?: boolean | undefined;
}>;
export type PluginManifest = z.infer<typeof plugin>;
export declare const anyAddon: z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged-theme">;
    main: z.ZodOptional<z.ZodString>;
    splash: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: "replugged-theme";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    main?: string | undefined;
    splash?: string | undefined;
}, {
    type: "replugged-theme";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    main?: string | undefined;
    splash?: string | undefined;
}>, z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged-plugin">;
    renderer: z.ZodOptional<z.ZodString>;
    plaintextPatches: z.ZodOptional<z.ZodString>;
    reloadRequired: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    type: "replugged-plugin";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    renderer?: string | undefined;
    plaintextPatches?: string | undefined;
    reloadRequired?: boolean | undefined;
}, {
    type: "replugged-plugin";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    renderer?: string | undefined;
    plaintextPatches?: string | undefined;
    reloadRequired?: boolean | undefined;
}>]>;
export type AnyAddonManifest = z.infer<typeof anyAddon>;
export declare const anyAddonOrReplugged: z.ZodDiscriminatedUnion<"type", [z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged">;
}, "strip", z.ZodTypeAny, {
    type: "replugged";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
}, {
    type: "replugged";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
}>, z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged-theme">;
    main: z.ZodOptional<z.ZodString>;
    splash: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    type: "replugged-theme";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    main?: string | undefined;
    splash?: string | undefined;
}, {
    type: "replugged-theme";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    main?: string | undefined;
    splash?: string | undefined;
}>, z.ZodObject<{
    name: z.ZodString;
    version: z.ZodString;
    description: z.ZodString;
    id: z.ZodString;
    author: z.ZodUnion<[z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        discordID: z.ZodOptional<z.ZodString>;
        github: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, {
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }>, "atleastone">]>;
    updater: z.ZodOptional<z.ZodObject<{
        type: z.ZodEnum<["store", "github"]>;
        id: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        type: "github" | "store";
        id: string;
    }, {
        type: "github" | "store";
        id: string;
    }>>;
    license: z.ZodString;
    image: z.ZodOptional<z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "atleastone">]>>;
    source: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<"replugged-plugin">;
    renderer: z.ZodOptional<z.ZodString>;
    plaintextPatches: z.ZodOptional<z.ZodString>;
    reloadRequired: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    type: "replugged-plugin";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    renderer?: string | undefined;
    plaintextPatches?: string | undefined;
    reloadRequired?: boolean | undefined;
}, {
    type: "replugged-plugin";
    name: string;
    version: string;
    description: string;
    id: string;
    author: ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]]) & ({
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    } | [{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }, ...{
        name: string;
        discordID?: string | undefined;
        github?: string | undefined;
    }[]] | undefined);
    license: string;
    updater?: {
        type: "github" | "store";
        id: string;
    } | undefined;
    image?: string | [string, ...string[]] | undefined;
    source?: string | undefined;
    renderer?: string | undefined;
    plaintextPatches?: string | undefined;
    reloadRequired?: boolean | undefined;
}>]>;
export type AnyAddonManifestOrReplugged = z.infer<typeof anyAddonOrReplugged>;
export interface PluginExports {
    start?: () => Promisable<void>;
    stop?: () => Promisable<void>;
    Settings?: React.ComponentType;
    [x: string]: unknown;
}
export type AddonSettings = {
    disabled?: string[];
};
